# Contributing

We absolutely welcome any code contributions and we hope that this
guide will facilitate an understanding of the Ansys Sphinx theme code
repository. It is important to note that while the Ansys Sphinx theme software
package is maintained by ANSYS, Inc. and any submissions will be reviewed
thoroughly before merging, we still seek to foster a community that can
support user questions and develop new features to make this software
a useful tool for all users. As such, we welcome and encourage any
questions or submissions to this repository.

For contributing to this project, please refer to the [PyAnsys Developer's Guide].
Further information about contributing to Ansys Sphinx theme can be found in [Contributing].

[PyAnsys Developer's Guide]: https://dev.docs.pyansys.com/index.html
[Contributing]: https://sphinxdocs.ansys.com/version/dev/contribute.html
